# remirepo spec file for php-pecl-dbase
#
# Copyright (c) 2015-2022 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%bcond_without     tests

# we don't want -z defs linker flag
%undefine _strict_symbol_defs_build

%if 0%{?scl:1}
%scl_package       php-pecl-dbase
%endif

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name  dbase
%global ini_name   40-%{pecl_name}.ini

%global upstream_version 7.1.1
#global upstream_prever  RC2

Summary:        dBase database file access functions
Name:           %{?scl_prefix}php-pecl-dbase
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release:        2%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        PHP
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{upstream_version}%{?upstream_prever}.tgz

Patch0:         %{pecl_name}-tests.patch

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.0
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
These functions allow you to access records stored
in dBase-format (dbf) databases.

There is no support for indexes or memo fields.
There is no support for locking, too.
Two concurrent webserver processes modifying the
same dBase file will very likely ruin your database.

dBase files are simple sequential files of fixed length records.
Records are appended to the end of the file and delete records
are kept until you call dbase_pack().

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl})}.


%prep
%setup -q -c
mv %{pecl_name}-%{upstream_version}%{?upstream_prever} NTS

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd NTS
%patch0 -p1

chmod -x *.c *.h
# Sanity check, really often broken
extver=$(sed -n '/#define PHP_DBASE_VERSION/{s/.* "//;s/".*$//;p}' php_dbase.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi
cd ..

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable %{summary} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --with-libdir=%{_lib} \
    --with-php-config=%{_bindir}/php-config

make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --with-libdir=%{_lib} \
    --with-php-config=%{_bindir}/zts-php-config

make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%check
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
cd NTS
: Upstream test suite for NTS extension
TEST_PHP_ARGS="-n -d extension_dir=$PWD/modules -d extension=%{pecl_name}.so" \
%{__php} -n run-tests.php -q -P --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
cd ../ZTS
: Upstream test suite for ZTS extension
TEST_PHP_ARGS="-n -d extension_dir=$PWD/modules -d extension=%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q -P --show-diff
%endif
%endif


%files
%{?_licensedir:%license NTS/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Mon Sep 12 2022 Remi Collet <remi@remirepo.net> - 7.1.1-2
- add upstream patch for test suite with PHP 8.2

* Sat Oct 30 2021 Remi Collet <remi@remirepo.net> - 7.1.1-1
- update to 7.1.1

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 7.1.0-2
- rebuild for 8.1.0RC1

* Mon Jun 14 2021 Remi Collet <remi@remirepo.net> - 7.1.0-1
- update to 7.1.0

* Mon Oct  5 2020 Remi Collet <remi@remirepo.net> - 7.1.0~RC2-1
- update to 7.1.0RC2

* Mon Oct 21 2019 Remi Collet <remi@remirepo.net> - 7.0.1-1
- update to 7.0.1

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 7.0.0-3
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 7.0.0-2
- rebuild for 7.4.0beta1

* Wed Apr 17 2019 Remi Collet <remi@remirepo.net> - 7.0.0-1
- update to 7.0.0 (stable)

* Thu Apr  4 2019 Remi Collet <remi@remirepo.net> - 7.0.0-0.7.RC1
- update to 7.0.0RC1
- add upstream patch to fix BC of dbase_create
- add upstream patch to fix test suite on 32-bit

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 7.0.0-0.6.beta1
- rebuild for 7.3.0beta2 new ABI

* Tue Jul 17 2018 Remi Collet <remi@remirepo.net> - 7.0.0-0.5.beta1
- rebuld for 7.3.0alpha4 new ABI

* Tue Jun 26 2018 Remi Collet <remi@remirepo.net> - 7.0.0-0.4.beta1
- cleanup and rebuild

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 7.0.0-0.3.beta1
- rebuild for PHP 7.2.0beta1 new API

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 7.0.0-0.2.beta1
- rebuild with PHP 7.1.0 GA

* Wed Oct 26 2016 Remi Collet <remi@fedoraproject.org> - 7.0.0-0.1.beta1
- update to 7.0.0beta1 for PHP 7

* Tue Mar  8 2016 Remi Collet <remi@fedoraproject.org> - 5.1.0-2
- adapt for F24

* Tue Aug 25 2015 Remi Collet <remi@fedoraproject.org> - 5.1.0-1
- initial package, version 5.1.0 (stable)

